All Classes and Interfaces
Class
Description
The
BaseBuilder provides the functionality to do base encoding and
decoding such as done by the Base64 encoding and decoding functionality (see
"https://en.wikipedia.org/wiki/Base64").The
BaseDecoder.BaseDecoderConnection implements the BaseDecoder
functionality in terms of a ConnectionComponent.InputStream decoding data being read.The
BaseDecoderOutputStream decodes encoded data written to this
stream and forwards the decoded bytes to an underlying OutputStream.The
BaseEncoder.BaseEncoderConnection implements the BaseEncoder
functionality in terms of a ConnectionComponent.The
BaseEncoderInputStream encodes data read from an underlying
InputStream using the configured BaseMetrics.The
BaseEncoderOutputStream is an implementations of the
BaseEncoder interface to be used with OutputStream instances.The
BaseMetrics provide the metrics for a codec to be used by an
implementation of the BaseBuilder, the BaseDecoder, the
BaseEncoder or the like.Provides an accessor for a base codec metrics property.
Provides a builder method for a base codec metrics property returning the
builder for applying multiple build operations.
Provides a mutator for a base codec metrics property.
Provides a base codec metrics property.
This enumeration provides access to preconfigured
BaseMetrics to be
used by a BaseBuilder, a BaseDecoder, a BaseEncoder
or the like..BaseMetrics implementation for playing around with your own
configuration.The Enum ChannelSelector.
Provides an accessor for a channel selector property.
Provides a builder method for a channel selector property returning the
builder for applying multiple build operations.
Provides a mutator for a channel selector property.
Provides a channel selector property.
The
Decoder provides a bridge to the "refcodes-io" artifact by
attaching to the BytesReceiver interface, thereby increasing the
usage scenarios of any Decoder implementation.The Enum DemodulatorStatus.
Provides an accessor for a Demodulator-Status property.
Provides a builder method for a Demodulator-Status property returning the
builder for applying multiple build operations.
Provides a mutator for a Demodulator-Status property.
Provides a Demodulator-Status property.
The
Encoder provides a bridge to the "refcodes-io" artifact by
attaching to the BytesTransmitter interface, thereby increasing the
usage scenarios of any Encoder implementation.The Enum FrequencyThreshold.
Provides an accessor for a frequency threshold property.
Provides a builder method for a frequency threshold property returning
the builder for applying multiple build operations.
Provides a mutator for a frequency threshold property.
Provides a frequency threshold property.
The
ModemDecoder implements a Frequency-shift keyring decoder. "...The
ModemDecoder.ModemByteDecoderProvider implements the ModemDecoder
functionality in terms of a ConnectionComponent.The
ModemDecoder.ModemShortDecoderProvider implements the ModemDecoder
functionality in terms of a ConnectionComponent.Vanilla plain implementation of the
ModemDecoder.ModemByteDecoderProvider
interface to be used with BytesDestination
(BytesReceiver) instances.Vanilla plain implementation of the
ModemDecoder.ModemByteDecoderProvider
interface to be used with BytesDestination
(BytesReceiver) instances.The
ModemEncoder implements a Frequency-shift keyring encoder. "...The
ModemEncoder.ModemEncoderConsumer implements the ModemEncoder
functionality in terms of a ConnectionComponent.The Interface ModemMetrics.
The Class ModemMetricsImpl.
The Enum ModemMode.
Provides an accessor for a Modem-Mode property.
Provides a builder method for a Modem-Mode property returning the builder
for applying multiple build operations.
Provides a mutator for a Modem-Mode property.
Provides a Modem-Mode property.
Pulse-code modulation format: Defines the according pulse-code modulation
format with the according silence threshold (root mean square).
Provides an accessor for a modulation format property.
Provides a builder method for a modulation format property returning the
builder for applying multiple build operations.
Provides a mutator for a modulation format property.
Provides a modulation format property.
The Enum ModulatorStatus.
Provides an accessor for a Modulator-Status property.
Provides a builder method for a Modulator-Status property returning the
builder for applying multiple build operations.
Provides a mutator for a Modulator-Status property.
Provides a Modulator-Status property.
The Enum SampleRate.
Provides an accessor for a sample rate property.
Provides a builder method for a sample rate property returning the
builder for applying multiple build operations.
Provides a mutator for a sample rate property.
Provides a sample rate property.