java.lang.Object
java.io.InputStream
org.refcodes.codec.BaseDecoderInputStream
- All Implemented Interfaces:
Closeable,AutoCloseable
InputStream decoding data being read.-
Constructor Summary
ConstructorsConstructorDescriptionBaseDecoderInputStream(File aInputFile, BaseMetrics aBaseMetrics) Constructs aBaseDecoderInputStreamusing the givenFilefrom which to read encoded data and using theBaseMetricsto decode the data.BaseDecoderInputStream(InputStream aInputStream, BaseMetrics aBaseMetrics) Constructs aBaseDecoderInputStreamusing the givenInputStreamfrom which to read encoded data and using theBaseMetricsto decode the data.BaseDecoderInputStream(InputStream aInputStream, BaseMetrics aBaseMetrics, boolean isFilterWhiteSpaces) Constructs aBaseDecoderInputStreamusing the givenInputStreamfrom which to read encoded data and using theBaseMetricsto decode the data. -
Method Summary
Methods inherited from class java.io.InputStream
mark, markSupported, nullInputStream, read, read, readAllBytes, readNBytes, readNBytes, reset, skip, skipNBytes, transferTo
-
Constructor Details
-
BaseDecoderInputStream
public BaseDecoderInputStream(InputStream aInputStream, BaseMetrics aBaseMetrics) throws IOException Constructs aBaseDecoderInputStreamusing the givenInputStreamfrom which to read encoded data and using theBaseMetricsto decode the data.- Parameters:
aInputStream- TheInputStreamfrom which to read encoded data.aBaseMetrics- TheBaseMetricsto use to decode the encoded data.- Throws:
IOException- throw in case using theInputStreamcaused I/O related problems.
-
BaseDecoderInputStream
public BaseDecoderInputStream(InputStream aInputStream, BaseMetrics aBaseMetrics, boolean isFilterWhiteSpaces) throws IOException Constructs aBaseDecoderInputStreamusing the givenInputStreamfrom which to read encoded data and using theBaseMetricsto decode the data.- Parameters:
aInputStream- TheInputStreamfrom which to read encoded data.aBaseMetrics- TheBaseMetricsto use to decode the encoded data.isFilterWhiteSpaces- When true, then all white spaces not found in theBaseMetrics.getCharSet()are filtered from theInputStream.- Throws:
IOException- throw in case using theInputStreamcaused I/O related problems.
-
BaseDecoderInputStream
Constructs aBaseDecoderInputStreamusing the givenFilefrom which to read encoded data and using theBaseMetricsto decode the data.- Parameters:
aInputFile- TheFilefrom which to read encoded data.aBaseMetrics- TheBaseMetricsto use to decode the encoded data.- Throws:
IOException- throw in case using theInputStreamcaused I/O related problems.
-
-
Method Details
-
read
- Specified by:
readin classInputStream- Throws:
IOException
-
close
- Specified by:
closein interfaceAutoCloseable- Specified by:
closein interfaceCloseable- Overrides:
closein classInputStream- Throws:
IOException
-
available
- Overrides:
availablein classInputStream- Throws:
IOException
-