- All Known Subinterfaces:
BaseMetricsAccessor.BaseMetricsProperty
- All Known Implementing Classes:
BaseBuilder,BaseDecoder,BaseDecoder.BaseDecoderConnection,BaseEncoder,BaseEncoder.BaseEncoderConnection
public interface BaseMetricsAccessor
Provides an accessor for a base codec metrics property.
-
Nested Class Summary
Nested ClassesModifier and TypeInterfaceDescriptionstatic interfaceProvides a builder method for a base codec metrics property returning the builder for applying multiple build operations.static interfaceProvides a mutator for a base codec metrics property.static interfaceProvides a base codec metrics property. -
Method Summary
Modifier and TypeMethodDescriptionRetrieves the base codec metrics from the base codec metrics property.
-
Method Details
-
getBaseMetrics
BaseMetrics getBaseMetrics()Retrieves the base codec metrics from the base codec metrics property.- Returns:
- The base codec metrics stored by the base codec metrics property.
-