- All Known Subinterfaces:
ChannelSelectorAccessor.ChannelSelectorProperty,ModemMetrics
- All Known Implementing Classes:
ModemMetricsImpl
public interface ChannelSelectorAccessor
Provides an accessor for a channel selector property.
-
Nested Class Summary
Nested ClassesModifier and TypeInterfaceDescriptionstatic interfaceChannelSelectorAccessor.ChannelSelectorBuilder<B extends ChannelSelectorAccessor.ChannelSelectorBuilder<B>>Provides a builder method for a channel selector property returning the builder for applying multiple build operations.static interfaceProvides a mutator for a channel selector property.static interfaceProvides a channel selector property. -
Method Summary
Modifier and TypeMethodDescriptionRetrieves the channel selector from the channel selector property.
-
Method Details
-
getChannelSelector
ChannelSelector getChannelSelector()Retrieves the channel selector from the channel selector property.- Returns:
- The channel selector stored by the channel selector property.
-