- java.lang.Object
-
- java.lang.Enum<ModemMode>
-
- org.refcodes.codec.ModemMode
-
- All Implemented Interfaces:
Serializable,Comparable<ModemMode>,org.refcodes.mixin.ModeAccessor<Integer>
public enum ModemMode extends Enum<ModemMode> implements org.refcodes.mixin.ModeAccessor<Integer>
The Enum ModemMode.
-
-
Enum Constant Summary
Enum Constants Enum Constant Description SOFT_MODEM_1SOFT_MODEM_2SOFT_MODEM_3SOFT_MODEM_4SOFT_MODEM_5
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description intgetBaudRate()The baud rate of this this mode.intgetHigherFrequency()The higher frequency for this mode.intgetLowerFrequency()The lower frequency for this mode.IntegergetMode()static ModemModevalueOf(String name)Returns the enum constant of this type with the specified name.static ModemMode[]values()Returns an array containing the constants of this enum type, in the order they are declared.
-
-
-
Enum Constant Detail
-
SOFT_MODEM_1
public static final ModemMode SOFT_MODEM_1
-
SOFT_MODEM_2
public static final ModemMode SOFT_MODEM_2
-
SOFT_MODEM_3
public static final ModemMode SOFT_MODEM_3
-
SOFT_MODEM_4
public static final ModemMode SOFT_MODEM_4
-
SOFT_MODEM_5
public static final ModemMode SOFT_MODEM_5
-
-
Method Detail
-
values
public static ModemMode[] values()
Returns an array containing the constants of this enum type, in the order they are declared. This method may be used to iterate over the constants as follows:for (ModemMode c : ModemMode.values()) System.out.println(c);
- Returns:
- an array containing the constants of this enum type, in the order they are declared
-
valueOf
public static ModemMode valueOf(String name)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum type has no constant with the specified nameNullPointerException- if the argument is null
-
getMode
public Integer getMode()
- Specified by:
getModein interfaceorg.refcodes.mixin.ModeAccessor<Integer>
-
getBaudRate
public int getBaudRate()
The baud rate of this this mode.- Returns:
- The baud rate.
-
getLowerFrequency
public int getLowerFrequency()
The lower frequency for this mode.- Returns:
- The lower frequency.
-
getHigherFrequency
public int getHigherFrequency()
The higher frequency for this mode.- Returns:
- The higher frequency.
-
-