Uses of Class
org.refcodes.codec.BaseBuilder
-
Uses of BaseBuilder in org.refcodes.codec
Classes in org.refcodes.codec that implement interfaces with type arguments of type BaseBuilderModifier and TypeClassDescriptionclassTheBaseBuilderprovides the functionality to do base encoding and decoding such as done by the Base64 encoding and decoding functionality (see "https://en.wikipedia.org/wiki/Base64").Methods in org.refcodes.codec that return BaseBuilderModifier and TypeMethodDescriptionBaseBuilder.withBaseMetrics(int aNumberBase) Sets the number base for the number base property.BaseBuilder.withBaseMetrics(BaseMetrics aBaseMetricsCodec) Sets the base codec metrics for the base codec metrics property.BaseBuilder.withDecodedData(byte[] aDecodedData) Sets the decoded data for the decoded data property.BaseBuilder.withDecodedData(long aDecodedData) Sets the decoded data for the decoded data property.BaseBuilder.withDecodedData(String aDecodedData) Sets the decoded data for the decoded data property.BaseBuilder.withDecodedData(String aDecodedData, String aCharset) Sets the decoded data for the decoded data property.BaseBuilder.withDecodedData(String aDecodedData, Charset aCharset) Sets the decoded data for the decoded data property.BaseBuilder.withEncodedText(String aEncodedText) Sets the encoded text for the encoded text property.