Uses of Interface
org.refcodes.codec.BaseMetrics
-
Uses of BaseMetrics in org.refcodes.codec
Classes in org.refcodes.codec that implement BaseMetricsModifier and TypeClassDescriptionenumThis enumeration provides access to preconfiguredBaseMetricsto be used by aBaseBuilder, aBaseDecoder, aBaseEncoderor the like..classBaseMetricsimplementation for playing around with your own configuration.Methods in org.refcodes.codec that return BaseMetricsModifier and TypeMethodDescriptionBaseBuilder.getBaseMetrics()Retrieves the base codec metrics from the base codec metrics property.BaseDecoder.getBaseMetrics()Retrieves the base codec metrics from the base codec metrics property.BaseEncoder.getBaseMetrics()Retrieves the base codec metrics from the base codec metrics property.BaseMetricsAccessor.getBaseMetrics()Retrieves the base codec metrics from the base codec metrics property.default BaseMetricsBaseMetricsAccessor.BaseMetricsProperty.letBaseMetrics(BaseMetrics aBaseMetrics) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenBaseMetrics(setter) as ofBaseMetricsAccessor.BaseMetricsMutator.setBaseMetrics(BaseMetrics)and returns the very same value (getter).static BaseMetricsBaseMetricsConfig.toBaseCodec(int aNumberBase) To base codec.Methods in org.refcodes.codec with parameters of type BaseMetricsModifier and TypeMethodDescriptiondefault BaseMetricsBaseMetricsAccessor.BaseMetricsProperty.letBaseMetrics(BaseMetrics aBaseMetrics) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenBaseMetrics(setter) as ofBaseMetricsAccessor.BaseMetricsMutator.setBaseMetrics(BaseMetrics)and returns the very same value (getter).voidBaseBuilder.setBaseMetrics(BaseMetrics aBaseMetrics) Sets the base codec metrics for the base codec metrics property.voidBaseDecoder.setBaseMetrics(BaseMetrics aBaseMetrics) Sets the base codec metrics for the base codec metrics property.voidBaseEncoder.setBaseMetrics(BaseMetrics aBaseMetrics) Sets the base codec metrics for the base codec metrics property.voidBaseMetricsAccessor.BaseMetricsMutator.setBaseMetrics(BaseMetrics aBaseMetrics) Sets the base codec metrics for the base codec metrics property.protected static intBaseBuilder.toBytes(byte[] aDecodedBytes, int aOffset, int aWord, int aTrailingBytes, BaseMetrics aBaseMetrics) To bytes.protected static byte[]BaseBuilder.toDecodedData(String aEncodedText, BaseMetrics aBaseMetrics) To decoded data.protected static intBaseBuilder.toDecodedSize(String aEncodedText, BaseMetrics aBaseMetrics) To decoded size.protected static StringBaseBuilder.toEncodedText(byte[] aDecodedData, BaseMetrics aBaseMetrics) To encoded text.BaseBuilder.withBaseMetrics(BaseMetrics aBaseMetricsCodec) Sets the base codec metrics for the base codec metrics property.BaseDecoder.withBaseMetrics(BaseMetrics aBaseMetrics) Sets the base codec metrics for the base codec metrics property.BaseEncoder.withBaseMetrics(BaseMetrics aBaseMetrics) Sets the base codec metrics for the base codec metrics property.BaseMetricsAccessor.BaseMetricsBuilder.withBaseMetrics(BaseMetrics aBaseMetrics) Sets the base codec metrics for the base codec metrics property.Constructors in org.refcodes.codec with parameters of type BaseMetricsModifierConstructorDescriptionBaseDecoder(InputStream aInputStream, BaseMetrics aBaseMetrics) Constructs theBaseDecoderreading the data to be decoded from the providedInputStream.BaseDecoder(org.refcodes.io.InputStreamByteReceiver aInputStreamByteReceiver, BaseMetrics aBaseMetrics) Constructs theBaseDecoderreading the data to be decoded from the providedInputStreamByteReceiver.BaseDecoderInputStream(File aInputFile, BaseMetrics aBaseMetrics) Constructs aBaseDecoderInputStreamusing the givenFilefrom which to read encoded data and using theBaseMetricsto decode the data.BaseDecoderInputStream(InputStream aInputStream, BaseMetrics aBaseMetrics) Constructs aBaseDecoderInputStreamusing the givenInputStreamfrom which to read encoded data and using theBaseMetricsto decode the data.BaseDecoderInputStream(InputStream aInputStream, BaseMetrics aBaseMetrics, boolean isFilterWhiteSpaces) Constructs aBaseDecoderInputStreamusing the givenInputStreamfrom which to read encoded data and using theBaseMetricsto decode the data.BaseEncoder(OutputStream aOutputStream, BaseMetrics aBaseMetrics) Constructs theBaseEncoderinstance using the providedOutputStreamto receive the encoded data.BaseEncoder(org.refcodes.io.OutputStreamBytesTransmitter aOutputStreamBytesTransmitter, BaseMetrics aBaseMetrics) Constructs theBaseEncoderinstance using the providedOutputStreamBytesTransmitterto receive the encoded data.BaseEncoderOutputStream(File aOutputFile, BaseMetrics aBaseMetrics) Constructs aBaseEncoderOutputStreamusing the givenFilefrom which to read decoded data and using theBaseMetricsto encode the data.BaseEncoderOutputStream(OutputStream aOutputStream, BaseMetrics aBaseMetrics) Constructs aBaseEncoderOutputStreamusing the givenOutputStreamfrom which to read decoded data and using theBaseMetricsto encode the data.BaseMetricsImpl(BaseMetrics aBaseMetrics) Instantiates a new base metrics impl.