Uses of Enum Class
org.refcodes.codec.BaseMetricsConfig
-
Uses of BaseMetricsConfig in org.refcodes.codec
Subclasses with type arguments of type BaseMetricsConfig in org.refcodes.codecModifier and TypeClassDescriptionenumThis enumeration provides access to preconfiguredBaseMetricsto be used by aBaseBuilder, aBaseDecoder, aBaseEncoderor the like..Methods in org.refcodes.codec that return BaseMetricsConfigModifier and TypeMethodDescriptionstatic BaseMetricsConfigReturns the enum constant of this class with the specified name.static BaseMetricsConfig[]BaseMetricsConfig.values()Returns an array containing the constants of this enum class, in the order they are declared.