Uses of Enum Class
org.refcodes.codec.ChannelSelector
-
Uses of ChannelSelector in org.refcodes.codec
Subclasses with type arguments of type ChannelSelector in org.refcodes.codecMethods in org.refcodes.codec that return ChannelSelectorModifier and TypeMethodDescriptionChannelSelectorAccessor.getChannelSelector()Retrieves the channel selector from the channel selector property.ModemMetricsImpl.getChannelSelector()Retrieves the channel selector from the channel selector property.default ChannelSelectorChannelSelectorAccessor.ChannelSelectorProperty.letChannelSelector(ChannelSelector aChannelSelector) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenChannelSelector(setter) as ofChannelSelectorAccessor.ChannelSelectorMutator.setChannelSelector(ChannelSelector)and returns the very same value (getter).static ChannelSelectorReturns the enum constant of this class with the specified name.static ChannelSelector[]ChannelSelector.values()Returns an array containing the constants of this enum class, in the order they are declared.Methods in org.refcodes.codec with parameters of type ChannelSelectorModifier and TypeMethodDescriptiondefault ChannelSelectorChannelSelectorAccessor.ChannelSelectorProperty.letChannelSelector(ChannelSelector aChannelSelector) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenChannelSelector(setter) as ofChannelSelectorAccessor.ChannelSelectorMutator.setChannelSelector(ChannelSelector)and returns the very same value (getter).voidChannelSelectorAccessor.ChannelSelectorMutator.setChannelSelector(ChannelSelector aChannelSelector) Sets the channel selector for the channel selector property.ChannelSelectorAccessor.ChannelSelectorBuilder.withChannelSelector(ChannelSelector aChannelSelector) Sets the channel selector for the channel selector property.Constructors in org.refcodes.codec with parameters of type ChannelSelectorModifierConstructorDescriptionModemMetricsImpl(SampleRate aSampleRate, ModulationFormat aModulationFormat, ChannelSelector aChannelSelector, ModemMode aModemModem, FrequencyThreshold aFrequencyThreshold) Instantiates a new modem metrics impl.