Uses of Enum Class
org.refcodes.codec.FrequencyThreshold
-
Uses of FrequencyThreshold in org.refcodes.codec
Methods in org.refcodes.codec that return FrequencyThresholdModifier and TypeMethodDescriptionFrequencyThresholdAccessor.getFrequencyThreshold()Retrieves the frequency threshold from the frequency threshold property.ModemMetricsImpl.getFrequencyThreshold()Retrieves the frequency threshold from the frequency threshold property.default FrequencyThresholdFrequencyThresholdAccessor.FrequencyThresholdProperty.letFrequencyThreshold(FrequencyThreshold aFrequencyThreshold) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenFrequencyThreshold(setter) as ofFrequencyThresholdAccessor.FrequencyThresholdMutator.setFrequencyThreshold(FrequencyThreshold)and returns the very same value (getter).static FrequencyThresholdReturns the enum constant of this class with the specified name.static FrequencyThreshold[]FrequencyThreshold.values()Returns an array containing the constants of this enum class, in the order they are declared.Methods in org.refcodes.codec with parameters of type FrequencyThresholdModifier and TypeMethodDescriptiondefault FrequencyThresholdFrequencyThresholdAccessor.FrequencyThresholdProperty.letFrequencyThreshold(FrequencyThreshold aFrequencyThreshold) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenFrequencyThreshold(setter) as ofFrequencyThresholdAccessor.FrequencyThresholdMutator.setFrequencyThreshold(FrequencyThreshold)and returns the very same value (getter).voidFrequencyThresholdAccessor.FrequencyThresholdMutator.setFrequencyThreshold(FrequencyThreshold aFrequencyThreshold) Sets the frequency threshold for the frequency threshold property.FrequencyThresholdAccessor.FrequencyThresholdBuilder.withFrequencyThreshold(FrequencyThreshold aFrequencyThreshold) Sets the frequency threshold for the frequency threshold property.Constructors in org.refcodes.codec with parameters of type FrequencyThresholdModifierConstructorDescriptionModemMetricsImpl(SampleRate aSampleRate, ModulationFormat aModulationFormat, ChannelSelector aChannelSelector, ModemMode aModemModem, FrequencyThreshold aFrequencyThreshold) Instantiates a new modem metrics impl.