Uses of Enum Class
org.refcodes.codec.ModemMode
-
Uses of ModemMode in org.refcodes.codec
Subclasses with type arguments of type ModemMode in org.refcodes.codecMethods in org.refcodes.codec that return ModemModeModifier and TypeMethodDescriptionModemMetricsImpl.getModemMode()Retrieves the Modem-Mode from the Modem-Mode property.ModemModeAccessor.getModemMode()Retrieves the Modem-Mode from the Modem-Mode property.default ModemModeModemModeAccessor.ModemModeProperty.letModemMode(ModemMode aModemMode) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenModemMode(setter) as ofModemModeAccessor.ModemModeMutator.setModemMode(ModemMode)and returns the very same value (getter).static ModemModeReturns the enum constant of this class with the specified name.static ModemMode[]ModemMode.values()Returns an array containing the constants of this enum class, in the order they are declared.Methods in org.refcodes.codec with parameters of type ModemModeModifier and TypeMethodDescriptiondefault ModemModeModemModeAccessor.ModemModeProperty.letModemMode(ModemMode aModemMode) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenModemMode(setter) as ofModemModeAccessor.ModemModeMutator.setModemMode(ModemMode)and returns the very same value (getter).voidModemModeAccessor.ModemModeMutator.setModemMode(ModemMode aModemMode) Sets the Modem-Mode for the Modem-Mode property.ModemModeAccessor.ModemModeBuilder.withModemMode(ModemMode aModemMode) Sets the Modem-Mode for the Modem-Mode property.Constructors in org.refcodes.codec with parameters of type ModemModeModifierConstructorDescriptionModemMetricsImpl(SampleRate aSampleRate, ModulationFormat aModulationFormat, ChannelSelector aChannelSelector, ModemMode aModemModem, FrequencyThreshold aFrequencyThreshold) Instantiates a new modem metrics impl.