Uses of Enum Class
org.refcodes.codec.SampleRate
-
Uses of SampleRate in org.refcodes.codec
Methods in org.refcodes.codec that return SampleRateModifier and TypeMethodDescriptionModemMetricsImpl.getSampleRate()Retrieves the sample rate from the sample rate property.SampleRateAccessor.getSampleRate()Retrieves the sample rate from the sample rate property.default SampleRateSampleRateAccessor.SampleRateProperty.letSampleRate(SampleRate aSampleRate) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenSampleRate(setter) as ofSampleRateAccessor.SampleRateMutator.setSampleRate(SampleRate)and returns the very same value (getter).static SampleRateReturns the enum constant of this class with the specified name.static SampleRate[]SampleRate.values()Returns an array containing the constants of this enum class, in the order they are declared.Methods in org.refcodes.codec with parameters of type SampleRateModifier and TypeMethodDescriptiondefault SampleRateSampleRateAccessor.SampleRateProperty.letSampleRate(SampleRate aSampleRate) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenSampleRate(setter) as ofSampleRateAccessor.SampleRateMutator.setSampleRate(SampleRate)and returns the very same value (getter).voidSampleRateAccessor.SampleRateMutator.setSampleRate(SampleRate aSampleRate) Sets the sample rate for the sample rate property.SampleRateAccessor.SampleRateBuilder.withSampleRate(SampleRate aSampleRate) Sets the sample rate for the sample rate property.Constructors in org.refcodes.codec with parameters of type SampleRateModifierConstructorDescriptionModemMetricsImpl(SampleRate aSampleRate, ModulationFormat aModulationFormat, ChannelSelector aChannelSelector, ModemMode aModemModem, FrequencyThreshold aFrequencyThreshold) Instantiates a new modem metrics impl.