Module org.refcodes.codec
Package org.refcodes.codec
package org.refcodes.codec
-
ClassDescriptionThe
BaseBuilderprovides the functionality to do base encoding and decoding such as done by the Base64 encoding and decoding functionality (see "https://en.wikipedia.org/wiki/Base64").TheBaseDecoder.BaseDecoderConnectionimplements theBaseDecoderfunctionality in terms of aConnectionComponent.InputStreamdecoding data being read.TheBaseEncoder.BaseEncoderConnectionimplements theBaseEncoderfunctionality in terms of aConnectionComponent.TheBaseEncoderOutputStreamis an implementations of theBaseEncoderinterface to be used withOutputStreaminstances.TheBaseMetricsprovide the metrics for a codec to be used by an implementation of theBaseBuilder, theBaseDecoder, theBaseEncoderor the like.Provides an accessor for a base codec metrics property.Provides a builder method for a base codec metrics property returning the builder for applying multiple build operations.Provides a mutator for a base codec metrics property.Provides a base codec metrics property.This enumeration provides access to pre-configuredBaseMetricsto be used by aBaseBuilder, aBaseDecoder, aBaseEncoderor the like..BaseMetricsimplementation for playing around with your own configuration.The Enum ChannelSelector.Provides an accessor for a channel selector property.ChannelSelectorAccessor.ChannelSelectorBuilder<B extends ChannelSelectorAccessor.ChannelSelectorBuilder<B>>Provides a builder method for a channel selector property returning the builder for applying multiple build operations.Provides a mutator for a channel selector property.Provides a channel selector property.The Enum DemodulatorStatus.Provides an accessor for a Demodulator-Status property.DemodulatorStatusAccessor.DemodulatorStatusBuilder<B extends DemodulatorStatusAccessor.DemodulatorStatusBuilder<B>>Provides a builder method for a Demodulator-Status property returning the builder for applying multiple build operations.Provides a mutator for a Demodulator-Status property.Provides a Demodulator-Status property.The Enum FrequencyThreshold.Provides an accessor for a frequency threshold property.FrequencyThresholdAccessor.FrequencyThresholdBuilder<B extends FrequencyThresholdAccessor.FrequencyThresholdBuilder<B>>Provides a builder method for a frequency threshold property returning the builder for applying multiple build operations.Provides a mutator for a frequency threshold property.Provides a frequency threshold property.TheModemDecoderimplements a Frequency-shift keyring decoder. "...TheModemDecoder.ModemByteDecoderProviderimplements theModemDecoderfunctionality in terms of aConnectionComponent.TheModemDecoder.ModemShortDecoderProviderimplements theModemDecoderfunctionality in terms of aConnectionComponent.Vanilla plain implementation of theModemDecoder.ModemByteDecoderProviderinterface to be used withBytesDestination(BytesReceiver) instances.Vanilla plain implementation of theModemDecoder.ModemByteDecoderProviderinterface to be used withBytesDestination(BytesReceiver) instances.TheModemEncoderimplements a Frequency-shift keyring encoder. "...TheModemEncoder.ModemEncoderConsumerimplements theModemEncoderfunctionality in terms of aConnectionComponent.The Interface ModemMetrics.The Class ModemMetricsImpl.The Enum ModemMode.Provides an accessor for a Modem-Mode property.Provides a builder method for a Modem-Mode property returning the builder for applying multiple build operations.Provides a mutator for a Modem-Mode property.Provides a Modem-Mode property.Pulse-code modulation format: Defines the according pulse-code modulation format with the according silence threshold (root mean square).Provides an accessor for a modulation format property.ModulationFormatAccessor.ModulationFormatBuilder<B extends ModulationFormatAccessor.ModulationFormatBuilder<B>>Provides a builder method for a modulation format property returning the builder for applying multiple build operations.Provides a mutator for a modulation format property.Provides a modulation format property.The Enum ModulatorStatus.Provides an accessor for a Modulator-Status property.ModulatorStatusAccessor.ModulatorStatusBuilder<B extends ModulatorStatusAccessor.ModulatorStatusBuilder<B>>Provides a builder method for a Modulator-Status property returning the builder for applying multiple build operations.Provides a mutator for a Modulator-Status property.Provides a Modulator-Status property.The Enum SampleRate.Provides an accessor for a sample rate property.Provides a builder method for a sample rate property returning the builder for applying multiple build operations.Provides a mutator for a sample rate property.Provides a sample rate property.