public interface BaseMetrics
extends org.refcodes.mixin.CharSetAccessor, org.refcodes.numerical.PaddingCharAccessor, org.refcodes.numerical.NumberBaseAccessor
BaseMetrics provide the metrics for a codec to be used by an
implementation of the BaseBuilder, the BaseDecoder, the
BaseEncoder or the like.org.refcodes.mixin.CharSetAccessor.CharSetBuilder<B extends org.refcodes.mixin.CharSetAccessor.CharSetBuilder<B>>, org.refcodes.mixin.CharSetAccessor.CharSetMutator, org.refcodes.mixin.CharSetAccessor.CharSetPropertyorg.refcodes.numerical.PaddingCharAccessor.PaddingCharBuilder<B extends org.refcodes.numerical.PaddingCharAccessor.PaddingCharBuilder<B>>, org.refcodes.numerical.PaddingCharAccessor.PaddingCharMutator, org.refcodes.numerical.PaddingCharAccessor.PaddingCharPropertyorg.refcodes.numerical.NumberBaseAccessor.NumberBaseBuilder<B extends org.refcodes.numerical.NumberBaseAccessor.NumberBaseBuilder<B>>, org.refcodes.numerical.NumberBaseAccessor.NumberBaseMutator, org.refcodes.numerical.NumberBaseAccessor.NumberBaseProperty| Modifier and Type | Method and Description |
|---|---|
int |
getBitsPerDigit()
Number in bits for one digit.
|
int |
getBytesPerInt()
Number of bytes to exactly store a minimum number of digits.
|
char[] |
getCharSet() |
int |
getDigitMask()
The digit mask is the bit-field covering just the digit's bits (starting
at bit 0).
|
int |
getDigitsPerByte()
Number of digits required to represent a byte.
|
int |
getDigitsPerInt()
Number of digits stored in an integer.
|
char |
toChar(int aValue)
Retrieves the (encoded) character for the (decoded) value.
|
int |
toValue(char aChar)
Retrieves the (decoded) value for the (encoded) character.
|
char[] getCharSet()
getCharSet in interface org.refcodes.mixin.CharSetAccessorint getBytesPerInt()
int getDigitsPerInt()
int getBitsPerDigit()
int getDigitsPerByte()
int getDigitMask()
int toValue(char aChar)
aChar - the a charchar toChar(int aValue)
aValue - the a valueCopyright © 2018. All rights reserved.