Serializable, Comparable<ChannelSelector>public enum ChannelSelector extends Enum<ChannelSelector>
| Modifier and Type | Method | Description |
|---|---|---|
static ChannelSelector |
valueOf(String name) |
Returns the enum constant of this type with the specified name.
|
static ChannelSelector[] |
values() |
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final ChannelSelector MONO
public static final ChannelSelector STEREO
public static ChannelSelector[] values()
for (ChannelSelector c : ChannelSelector.values()) System.out.println(c);
public static ChannelSelector valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullCopyright © 2018. All rights reserved.