Package org.refcodes.codec
Interface ChannelSelectorAccessor
-
- All Known Subinterfaces:
ChannelSelectorAccessor.ChannelSelectorProperty,ModemMetrics
- All Known Implementing Classes:
ModemMetricsImpl
public interface ChannelSelectorAccessorProvides an accessor for a channel selector property.
-
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceChannelSelectorAccessor.ChannelSelectorBuilder<B extends ChannelSelectorAccessor.ChannelSelectorBuilder<B>>Provides a builder method for a channel selector property returning the builder for applying multiple build operations.static interfaceChannelSelectorAccessor.ChannelSelectorMutatorProvides a mutator for a channel selector property.static interfaceChannelSelectorAccessor.ChannelSelectorPropertyProvides a channel selector property.
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description ChannelSelectorgetChannelSelector()Retrieves the channel selector from the channel selector property.
-
-
-
Method Detail
-
getChannelSelector
ChannelSelector getChannelSelector()
Retrieves the channel selector from the channel selector property.- Returns:
- The channel selector stored by the channel selector property.
-
-