public class ModemMetricsImpl extends Object implements ModemMetrics
SampleRateAccessor.SampleRateBuilder<B extends SampleRateAccessor.SampleRateBuilder<B>>, SampleRateAccessor.SampleRateMutator, SampleRateAccessor.SampleRatePropertyModulationFormatAccessor.ModulationFormatBuilder<B extends ModulationFormatAccessor.ModulationFormatBuilder<B>>, ModulationFormatAccessor.ModulationFormatMutator, ModulationFormatAccessor.ModulationFormatPropertyChannelSelectorAccessor.ChannelSelectorBuilder<B extends ChannelSelectorAccessor.ChannelSelectorBuilder<B>>, ChannelSelectorAccessor.ChannelSelectorMutator, ChannelSelectorAccessor.ChannelSelectorPropertyModemModeAccessor.ModemModeBuilder<B extends ModemModeAccessor.ModemModeBuilder<B>>, ModemModeAccessor.ModemModeMutator, ModemModeAccessor.ModemModePropertyFrequencyThresholdAccessor.FrequencyThresholdBuilder<B extends FrequencyThresholdAccessor.FrequencyThresholdBuilder<B>>, FrequencyThresholdAccessor.FrequencyThresholdMutator, FrequencyThresholdAccessor.FrequencyThresholdProperty| Constructor and Description |
|---|
ModemMetricsImpl(SampleRate aSampleRate,
ModulationFormat aModulationFormat,
ChannelSelector aChannelSelector,
ModemMode aModemModem,
FrequencyThreshold aFrequencyThreshold)
Instantiates a new modem metrics impl.
|
| Modifier and Type | Method and Description |
|---|---|
ChannelSelector |
getChannelSelector()
Retrieves the channel selector from the channel selector property.
|
FrequencyThreshold |
getFrequencyThreshold()
Retrieves the frequency threshold from the frequency threshold property.
|
ModemMode |
getModemMode()
Retrieves the Modem-Mode from the Modem-Mode property.
|
ModulationFormat |
getModulationFormat()
Retrieves the modulation format from the pulse-code modulation format
property.
|
SampleRate |
getSampleRate()
Retrieves the sample rate from the sample rate property.
|
int |
toHigherFrequencyUpperThreshold()
Calculates the upper threshold for the higher frequency.
|
int |
toLowerFrequencyUpperThreshold()
Calculates the upper threshold for the lower frequency.
|
int |
toSamplesPerBit()
Calculates the samples per bit.
|
public ModemMetricsImpl(SampleRate aSampleRate, ModulationFormat aModulationFormat, ChannelSelector aChannelSelector, ModemMode aModemModem, FrequencyThreshold aFrequencyThreshold)
aSampleRate - the a sample rateaModulationFormat - the a modulation formataChannelSelector - the a channel selectoraModemModem - the a modem modemaFrequencyThreshold - the a frequency thresholdpublic SampleRate getSampleRate()
getSampleRate in interface SampleRateAccessorpublic ModulationFormat getModulationFormat()
getModulationFormat in interface ModulationFormatAccessorpublic ChannelSelector getChannelSelector()
getChannelSelector in interface ChannelSelectorAccessorpublic ModemMode getModemMode()
getModemMode in interface ModemModeAccessorpublic FrequencyThreshold getFrequencyThreshold()
getFrequencyThreshold in interface FrequencyThresholdAccessorpublic int toHigherFrequencyUpperThreshold()
toHigherFrequencyUpperThreshold in interface ModemMetricspublic int toLowerFrequencyUpperThreshold()
toLowerFrequencyUpperThreshold in interface ModemMetricspublic int toSamplesPerBit()
toSamplesPerBit in interface ModemMetricsCopyright © 2018. All rights reserved.