Serializable, Comparable<ModulatorStatus>public enum ModulatorStatus extends Enum<ModulatorStatus>
| Enum Constant | Description |
|---|---|
ENCODING |
|
IDLE |
|
POST_CARRIER |
|
PRE_CARRIER |
|
SILENCE |
| Modifier and Type | Method | Description |
|---|---|---|
static ModulatorStatus |
valueOf(String name) |
Returns the enum constant of this type with the specified name.
|
static ModulatorStatus[] |
values() |
Returns an array containing the constants of this enum type, in
the order they are declared.
|
public static final ModulatorStatus IDLE
public static final ModulatorStatus PRE_CARRIER
public static final ModulatorStatus ENCODING
public static final ModulatorStatus POST_CARRIER
public static final ModulatorStatus SILENCE
public static ModulatorStatus[] values()
for (ModulatorStatus c : ModulatorStatus.values()) System.out.println(c);
public static ModulatorStatus valueOf(String name)
name - the name of the enum constant to be returned.IllegalArgumentException - if this enum type has no constant with the specified nameNullPointerException - if the argument is nullCopyright © 2018. All rights reserved.