Uses of Interface
org.refcodes.codec.BaseBuilder
-
-
Uses of BaseBuilder in org.refcodes.codec
Classes in org.refcodes.codec that implement BaseBuilder Modifier and Type Class Description classBaseBuilderImplVanilla plain implementation of theBaseBuilderinterface.Methods in org.refcodes.codec that return BaseBuilder Modifier and Type Method Description default BaseBuilderBaseBuilder. withBaseMetrics(int aNumberBase)Sets the number base for the number base property.default BaseBuilderBaseBuilder. withBaseMetrics(BaseMetrics aBaseMetricsCodec)Sets the base codec metrics for the base codec metrics property.default BaseBuilderBaseBuilder. withDecodedData(byte[] aDecodedData)Sets the decoded data for the decoded data property.default BaseBuilderBaseBuilder. withDecodedData(long aDecodedData)Sets the decoded data for the decoded data property.default BaseBuilderBaseBuilder. withEncodedText(java.lang.String aEncodedText)Sets the encoded text for the encoded text property.
-