| Modifier and Type | Method and Description |
|---|---|
DemodulatorStatus |
DemodulatorStatusAccessor.getDemodulatorStatus()
Retrieves the Demodulator-Status from the Demodulator-Status property.
|
static DemodulatorStatus |
DemodulatorStatus.valueOf(String name)
Returns the enum constant of this type with the specified name.
|
static DemodulatorStatus[] |
DemodulatorStatus.values()
Returns an array containing the constants of this enum type, in
the order they are declared.
|
| Modifier and Type | Method and Description |
|---|---|
void |
DemodulatorStatusAccessor.DemodulatorStatusMutator.setDemodulatorStatus(DemodulatorStatus aDemodulatorStatus)
Sets the Demodulator-Status for the Demodulator-Status property.
|
B |
DemodulatorStatusAccessor.DemodulatorStatusBuilder.withDemodulatorStatus(DemodulatorStatus aDemodulatorStatus)
Sets the Demodulator-Status for the Demodulator-Status property.
|
Copyright © 2018. All rights reserved.