Uses of Class
org.refcodes.codec.ModemMode
-
-
Uses of ModemMode in org.refcodes.codec
Methods in org.refcodes.codec that return ModemMode Modifier and Type Method Description ModemModeModemMetricsImpl. getModemMode()Retrieves the Modem-Mode from the Modem-Mode property.ModemModeModemModeAccessor. getModemMode()Retrieves the Modem-Mode from the Modem-Mode property.static ModemModeModemMode. valueOf(java.lang.String name)Returns the enum constant of this type with the specified name.static ModemMode[]ModemMode. values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in org.refcodes.codec with parameters of type ModemMode Modifier and Type Method Description voidModemModeAccessor.ModemModeMutator. setModemMode(ModemMode aModemMode)Sets the Modem-Mode for the Modem-Mode property.BModemModeAccessor.ModemModeBuilder. withModemMode(ModemMode aModemMode)Sets the Modem-Mode for the Modem-Mode property.Constructors in org.refcodes.codec with parameters of type ModemMode Constructor Description ModemMetricsImpl(SampleRate aSampleRate, ModulationFormat aModulationFormat, ChannelSelector aChannelSelector, ModemMode aModemModem, FrequencyThreshold aFrequencyThreshold)Instantiates a new modem metrics impl.
-