Uses of Class
org.refcodes.codec.ModulationFormat
-
-
Uses of ModulationFormat in org.refcodes.codec
Methods in org.refcodes.codec that return ModulationFormat Modifier and Type Method Description ModulationFormatModemMetricsImpl. getModulationFormat()Retrieves the modulation format from the pulse-code modulation format property.ModulationFormatModulationFormatAccessor. getModulationFormat()Retrieves the modulation format from the pulse-code modulation format property.static ModulationFormatModulationFormat. valueOf(java.lang.String name)Returns the enum constant of this type with the specified name.static ModulationFormat[]ModulationFormat. values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in org.refcodes.codec with parameters of type ModulationFormat Modifier and Type Method Description voidModulationFormatAccessor.ModulationFormatMutator. setModulationFormat(ModulationFormat aModulationFormat)Sets the modulation format for the pulse-code modulation format property.BModulationFormatAccessor.ModulationFormatBuilder. withModulationFormat(ModulationFormat aModulationFormat)Sets the modulation format for the pulse-code modulation format property.Constructors in org.refcodes.codec with parameters of type ModulationFormat Constructor Description ModemMetricsImpl(SampleRate aSampleRate, ModulationFormat aModulationFormat, ChannelSelector aChannelSelector, ModemMode aModemModem, FrequencyThreshold aFrequencyThreshold)Instantiates a new modem metrics impl.
-