public class BaseCodecBuilderImpl extends Object implements BaseCodecBuilder
BaseCodecMetricsAccessor.BaseCodecMetricsBuilder<B extends BaseCodecMetricsAccessor.BaseCodecMetricsBuilder<B>>, BaseCodecMetricsAccessor.BaseCodecMetricsMutator, BaseCodecMetricsAccessor.BaseCodecMetricsProperty| Constructor and Description |
|---|
BaseCodecBuilderImpl() |
| Modifier and Type | Method and Description |
|---|---|
BaseCodecMetrics |
getBaseCodecMetrics()
Retrieves the base codec metrics from the base codec metrics property.
|
byte[] |
getDecodedData()
Retrieves the decoded data from the decoded data property.
|
String |
getEncodedText()
Retrieves the encoded text from the encoded text property.
|
void |
setBaseCodecMetrics(BaseCodecMetrics aBaseCodecMetrics)
Sets the base codec metrics for the base codec metrics property.
|
void |
setDecodedData(byte[] aDecodedData)
Sets the decoded data for the decoded data property.
|
void |
setDecodedData(long aDecodedData)
Sets the decoded data for the decoded data property.
|
void |
setEncodedText(String aEncodedText)
Sets the encoded text for the encoded text property.
|
protected static int |
toBytes(byte[] aDecodedBytes,
int aOffset,
int aWord,
int aTrailingBytes,
BaseCodecMetrics aBaseCodecMetrics) |
byte[] |
toDecodedData(String aEncodedText)
Retrieves the decoded data calculated from the provided encoded text.
|
protected static int |
toDecodedSize(String aEncodedText,
BaseCodecMetrics aBaseCodecMetrics) |
String |
toEncodedText(byte[] aDecodedData)
Retrieves the encoded text calculated from the decoded data.
|
String |
toEncodedText(long aDecodedData)
Retrieves the encoded text calculated from the decoded data.
|
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, waitsetBaseCodecMetrics, withBaseCodecMetrics, withBaseCodecMetrics, withDecodedData, withDecodedData, withEncodedTextpublic BaseCodecMetrics getBaseCodecMetrics()
BaseCodecMetricsAccessorgetBaseCodecMetrics in interface BaseCodecMetricsAccessorpublic void setBaseCodecMetrics(BaseCodecMetrics aBaseCodecMetrics)
BaseCodecMetricsAccessor.BaseCodecMetricsMutatorsetBaseCodecMetrics in interface BaseCodecMetricsAccessor.BaseCodecMetricsMutatoraBaseCodecMetrics - The base codec metrics to be stored by the
font style property.public String getEncodedText()
BaseCodecBuildergetEncodedText in interface BaseCodecBuilderpublic void setEncodedText(String aEncodedText)
BaseCodecBuildersetEncodedText in interface BaseCodecBuilderaEncodedText - The encoded text to be stored by the encoded text
property.public byte[] getDecodedData()
BaseCodecBuildergetDecodedData in interface BaseCodecBuilderpublic void setDecodedData(byte[] aDecodedData)
BaseCodecBuildersetDecodedData in interface BaseCodecBuilderaDecodedData - The decoded data to be stored by the decoded data
property.public void setDecodedData(long aDecodedData)
BaseCodecBuildersetDecodedData in interface BaseCodecBuilderaDecodedData - The decoded data to be stored by the decoded data
property.public String toEncodedText(byte[] aDecodedData)
BaseCodecBuilderBaseCodecMetrics via
BaseCodecBuilder.withBaseCodecMetrics(BaseCodecMetrics) can cause side effects!
For avoiding thread race conditions / side effects regarding the decoded
data (and the encoded result), use this method instead of the combination
of BaseCodecBuilder.withDecodedData(byte[]) with BaseCodecBuilder.getEncodedText()toEncodedText in interface BaseCodecBuilderaDecodedData - The decoded data to be encoded.public byte[] toDecodedData(String aEncodedText)
BaseCodecBuilderBaseCodecMetrics via
BaseCodecBuilder.withBaseCodecMetrics(BaseCodecMetrics) can cause side effects!
For avoiding thread race conditions / side effects regarding the encoded
text (and the decoded result), use this method instead of the combination
of BaseCodecBuilder.withEncodedText(String) with BaseCodecBuilder.getDecodedData().toDecodedData in interface BaseCodecBuilderaEncodedText - The encoded text to be decoded.public String toEncodedText(long aDecodedData)
BaseCodecBuilderBaseCodecMetrics via
BaseCodecBuilder.withBaseCodecMetrics(BaseCodecMetrics) can cause side effects!
For avoiding thread race conditions / side effects regarding the decoded
data (and the encoded result), use this method instead of the combination
of BaseCodecBuilder.withDecodedData(byte[]) with BaseCodecBuilder.getEncodedText()toEncodedText in interface BaseCodecBuilderaDecodedData - The decoded data to be encoded.protected static int toDecodedSize(String aEncodedText, BaseCodecMetrics aBaseCodecMetrics)
protected static int toBytes(byte[] aDecodedBytes,
int aOffset,
int aWord,
int aTrailingBytes,
BaseCodecMetrics aBaseCodecMetrics)
Copyright © 2016. All rights reserved.