| Interface | Description |
|---|---|
| BaseCodecBuilder |
The
BaseCodecBuilder provides the functionality to do base encoding
and decoding such as done by the Base64 encoding and decoding functionality
(see "https://en.wikipedia.org/wiki/Base64"). |
| BaseCodecMetrics |
The
BaseCodecMetrics provide the metrics for a codec to be used by an
implementation of the BaseCodecBuilder, the
BaseDecodeReceiver, the BaseEncodeSender or the like. |
| BaseCodecMetricsAccessor |
Provides an accessor for a base codec metrics property.
|
| BaseCodecMetricsAccessor.BaseCodecMetricsBuilder<B extends BaseCodecMetricsAccessor.BaseCodecMetricsBuilder<B>> |
Provides a builder method for a base codec metrics property returning the
builder for applying multiple build operations.
|
| BaseCodecMetricsAccessor.BaseCodecMetricsMutator |
Provides a mutator for a base codec metrics property.
|
| BaseCodecMetricsAccessor.BaseCodecMetricsProperty |
Provides a base codec metrics property.
|
| BaseDecodeReceiver |
The
BaseDecodeReceiver implements the BaseCodecBuilder
functionality in terms of a ByteReceiver.It implements the
DecodeReceiver interface attaching to the "refcodes-io" artifact via
the ByteReceiver interface. |
| BaseEncodeSender |
The
BaseEncodeSender implements the BaseCodecBuilder
functionality in terms of a ByteSender.It implements the
EncodeSender interface attaching to the "refcodes-io" artifact via
the EncodeSender interface. |
| DecodeReceiver |
The
DecodeReceiver provides a bridge to the "refcodes-io" artifact by
attaching to the ByteReceiver interface, thereby increasing the usage
scenarios of any DecodeReceiver implementation. |
| EncodeSender |
The
EncodeSender provides a bridge to the "refcodes-io" artifact by
attaching to the ByteSender interface, thereby increasing the usage
scenarios of any EncodeSender implementation. |
| Enum | Description |
|---|---|
| BaseCodecConfig |
This enumeration provides access to pre-configured
BaseCodecMetrics
to be used by a BaseCodecBuilder, a BaseDecodeReceiver, a
BaseEncodeSender or the like.. |
Copyright © 2017. All rights reserved.