- java.lang.Object
-
- java.io.InputStream
-
- org.refcodes.codec.BaseDecoderInputStream
-
- All Implemented Interfaces:
Closeable,AutoCloseable
public class BaseDecoderInputStream extends InputStream
InputStreamdecoding data being read.
-
-
Constructor Summary
Constructors Constructor Description BaseDecoderInputStream(File aInputFile, BaseMetrics aBaseMetrics)Constructs aBaseDecoderInputStreamusing the givenFilefrom which to read encoded data and using theBaseMetricsto decode the data.BaseDecoderInputStream(InputStream aInputStream, BaseMetrics aBaseMetrics)Constructs aBaseDecoderInputStreamusing the givenInputStreamfrom which to read encoded data and using theBaseMetricsto decode the data.BaseDecoderInputStream(InputStream aInputStream, BaseMetrics aBaseMetrics, boolean isFilterWhiteSpaces)Constructs aBaseDecoderInputStreamusing the givenInputStreamfrom which to read encoded data and using theBaseMetricsto decode the data.
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description intavailable()voidclose()intread()-
Methods inherited from class java.io.InputStream
mark, markSupported, nullInputStream, read, read, readAllBytes, readNBytes, readNBytes, reset, skip, transferTo
-
-
-
-
Constructor Detail
-
BaseDecoderInputStream
public BaseDecoderInputStream(InputStream aInputStream, BaseMetrics aBaseMetrics) throws IOException
Constructs aBaseDecoderInputStreamusing the givenInputStreamfrom which to read encoded data and using theBaseMetricsto decode the data.- Parameters:
aInputStream- TheInputStreamfrom which to read encoded data.aBaseMetrics- TheBaseMetricsto use to decode the encoded data.- Throws:
IOException- throw in case using theInputStreamcaused I/O related problems.
-
BaseDecoderInputStream
public BaseDecoderInputStream(InputStream aInputStream, BaseMetrics aBaseMetrics, boolean isFilterWhiteSpaces) throws IOException
Constructs aBaseDecoderInputStreamusing the givenInputStreamfrom which to read encoded data and using theBaseMetricsto decode the data.- Parameters:
aInputStream- TheInputStreamfrom which to read encoded data.aBaseMetrics- TheBaseMetricsto use to decode the encoded data.isFilterWhiteSpaces- When true, then all white spaces not found in theBaseMetrics.getCharSet()are filtered from theInputStream.- Throws:
IOException- throw in case using theInputStreamcaused I/O related problems.
-
BaseDecoderInputStream
public BaseDecoderInputStream(File aInputFile, BaseMetrics aBaseMetrics) throws IOException
Constructs aBaseDecoderInputStreamusing the givenFilefrom which to read encoded data and using theBaseMetricsto decode the data.- Parameters:
aInputFile- TheFilefrom which to read encoded data.aBaseMetrics- TheBaseMetricsto use to decode the encoded data.- Throws:
IOException- throw in case using theInputStreamcaused I/O related problems.
-
-
Method Detail
-
read
public int read() throws IOException- Specified by:
readin classInputStream- Throws:
IOException
-
close
public void close() throws IOException- Specified by:
closein interfaceAutoCloseable- Specified by:
closein interfaceCloseable- Overrides:
closein classInputStream- Throws:
IOException
-
available
public int available() throws IOException- Overrides:
availablein classInputStream- Throws:
IOException
-
-