- All Implemented Interfaces:
Serializable,Comparable<ModemMode>,java.lang.constant.Constable,org.refcodes.mixin.ModeAccessor<Integer>
public enum ModemMode extends Enum<ModemMode> implements org.refcodes.mixin.ModeAccessor<Integer>
The Enum ModemMode.
-
Nested Class Summary
Nested classes/interfaces inherited from class java.lang.Enum
Enum.EnumDesc<E extends Enum<E>> -
Enum Constant Summary
Enum Constants Enum Constant Description SOFT_MODEM_1SOFT_MODEM_2SOFT_MODEM_3SOFT_MODEM_4SOFT_MODEM_5 -
Method Summary
Modifier and Type Method Description intgetBaudRate()The baud rate of this this mode.intgetHigherFrequency()The higher frequency for this mode.intgetLowerFrequency()The lower frequency for this mode.IntegergetMode()static ModemModevalueOf(String name)Returns the enum constant of this type with the specified name.static ModemMode[]values()Returns an array containing the constants of this enum type, in the order they are declared.
-
Enum Constant Details
-
SOFT_MODEM_1
-
SOFT_MODEM_2
-
SOFT_MODEM_3
-
SOFT_MODEM_4
-
SOFT_MODEM_5
-
-
Method Details
-
values
Returns an array containing the constants of this enum type, in the order they are declared.- Returns:
- an array containing the constants of this enum type, in the order they are declared
-
valueOf
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum type has no constant with the specified nameNullPointerException- if the argument is null
-
getMode
- Specified by:
getModein interfaceorg.refcodes.mixin.ModeAccessor<Integer>
-
getBaudRate
public int getBaudRate()The baud rate of this this mode.- Returns:
- The baud rate.
-
getLowerFrequency
public int getLowerFrequency()The lower frequency for this mode.- Returns:
- The lower frequency.
-
getHigherFrequency
public int getHigherFrequency()The higher frequency for this mode.- Returns:
- The higher frequency.
-