Uses of Enum Class
org.refcodes.codec.BaseMetricsConfig
-
Uses of BaseMetricsConfig in org.refcodes.codec
Methods in org.refcodes.codec that return BaseMetricsConfigModifier and TypeMethodDescriptionstatic BaseMetricsConfigReturns the enum constant of this class with the specified name.static BaseMetricsConfig[]BaseMetricsConfig.values()Returns an array containing the constants of this enum class, in the order they are declared.