Uses of Enum
org.refcodes.codec.BaseMetricsConfig
-
Uses of BaseMetricsConfig in org.refcodes.codec
Methods in org.refcodes.codec that return BaseMetricsConfigModifier and TypeMethodDescriptionstatic BaseMetricsConfigReturns the enum constant of this type with the specified name.static BaseMetricsConfig[]BaseMetricsConfig.values()Returns an array containing the constants of this enum type, in the order they are declared.