Uses of Class
org.refcodes.codec.ChannelSelector
-
-
Uses of ChannelSelector in org.refcodes.codec
Methods in org.refcodes.codec that return ChannelSelector Modifier and Type Method Description ChannelSelectorChannelSelectorAccessor. getChannelSelector()Retrieves the channel selector from the channel selector property.ChannelSelectorModemMetricsImpl. getChannelSelector()Retrieves the channel selector from the channel selector property.default ChannelSelectorChannelSelectorAccessor.ChannelSelectorProperty. letChannelSelector(ChannelSelector aChannelSelector)This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenChannelSelector(setter) as ofChannelSelectorAccessor.ChannelSelectorMutator.setChannelSelector(ChannelSelector)and returns the very same value (getter).static ChannelSelectorChannelSelector. valueOf(String name)Returns the enum constant of this type with the specified name.static ChannelSelector[]ChannelSelector. values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in org.refcodes.codec with parameters of type ChannelSelector Modifier and Type Method Description default ChannelSelectorChannelSelectorAccessor.ChannelSelectorProperty. letChannelSelector(ChannelSelector aChannelSelector)This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenChannelSelector(setter) as ofChannelSelectorAccessor.ChannelSelectorMutator.setChannelSelector(ChannelSelector)and returns the very same value (getter).voidChannelSelectorAccessor.ChannelSelectorMutator. setChannelSelector(ChannelSelector aChannelSelector)Sets the channel selector for the channel selector property.BChannelSelectorAccessor.ChannelSelectorBuilder. withChannelSelector(ChannelSelector aChannelSelector)Sets the channel selector for the channel selector property.Constructors in org.refcodes.codec with parameters of type ChannelSelector Constructor Description ModemMetricsImpl(SampleRate aSampleRate, ModulationFormat aModulationFormat, ChannelSelector aChannelSelector, ModemMode aModemModem, FrequencyThreshold aFrequencyThreshold)Instantiates a new modem metrics impl.
-