Uses of Class
org.refcodes.codec.FrequencyThreshold
-
-
Uses of FrequencyThreshold in org.refcodes.codec
Methods in org.refcodes.codec that return FrequencyThreshold Modifier and Type Method Description FrequencyThresholdFrequencyThresholdAccessor. getFrequencyThreshold()Retrieves the frequency threshold from the frequency threshold property.FrequencyThresholdModemMetricsImpl. getFrequencyThreshold()Retrieves the frequency threshold from the frequency threshold property.default FrequencyThresholdFrequencyThresholdAccessor.FrequencyThresholdProperty. letFrequencyThreshold(FrequencyThreshold aFrequencyThreshold)This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenFrequencyThreshold(setter) as ofFrequencyThresholdAccessor.FrequencyThresholdMutator.setFrequencyThreshold(FrequencyThreshold)and returns the very same value (getter).static FrequencyThresholdFrequencyThreshold. valueOf(String name)Returns the enum constant of this type with the specified name.static FrequencyThreshold[]FrequencyThreshold. values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in org.refcodes.codec with parameters of type FrequencyThreshold Modifier and Type Method Description default FrequencyThresholdFrequencyThresholdAccessor.FrequencyThresholdProperty. letFrequencyThreshold(FrequencyThreshold aFrequencyThreshold)This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenFrequencyThreshold(setter) as ofFrequencyThresholdAccessor.FrequencyThresholdMutator.setFrequencyThreshold(FrequencyThreshold)and returns the very same value (getter).voidFrequencyThresholdAccessor.FrequencyThresholdMutator. setFrequencyThreshold(FrequencyThreshold aFrequencyThreshold)Sets the frequency threshold for the frequency threshold property.BFrequencyThresholdAccessor.FrequencyThresholdBuilder. withFrequencyThreshold(FrequencyThreshold aFrequencyThreshold)Sets the frequency threshold for the frequency threshold property.Constructors in org.refcodes.codec with parameters of type FrequencyThreshold Constructor Description ModemMetricsImpl(SampleRate aSampleRate, ModulationFormat aModulationFormat, ChannelSelector aChannelSelector, ModemMode aModemModem, FrequencyThreshold aFrequencyThreshold)Instantiates a new modem metrics impl.
-