Uses of Class
org.refcodes.codec.ModemMode
-
-
Uses of ModemMode in org.refcodes.codec
Methods in org.refcodes.codec that return ModemMode Modifier and Type Method Description ModemModeModemMetricsImpl. getModemMode()Retrieves the Modem-Mode from the Modem-Mode property.ModemModeModemModeAccessor. getModemMode()Retrieves the Modem-Mode from the Modem-Mode property.default ModemModeModemModeAccessor.ModemModeProperty. letModemMode(ModemMode aModemMode)This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenModemMode(setter) as ofModemModeAccessor.ModemModeMutator.setModemMode(ModemMode)and returns the very same value (getter).static ModemModeModemMode. valueOf(String name)Returns the enum constant of this type with the specified name.static ModemMode[]ModemMode. values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in org.refcodes.codec with parameters of type ModemMode Modifier and Type Method Description default ModemModeModemModeAccessor.ModemModeProperty. letModemMode(ModemMode aModemMode)This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenModemMode(setter) as ofModemModeAccessor.ModemModeMutator.setModemMode(ModemMode)and returns the very same value (getter).voidModemModeAccessor.ModemModeMutator. setModemMode(ModemMode aModemMode)Sets the Modem-Mode for the Modem-Mode property.BModemModeAccessor.ModemModeBuilder. withModemMode(ModemMode aModemMode)Sets the Modem-Mode for the Modem-Mode property.Constructors in org.refcodes.codec with parameters of type ModemMode Constructor Description ModemMetricsImpl(SampleRate aSampleRate, ModulationFormat aModulationFormat, ChannelSelector aChannelSelector, ModemMode aModemModem, FrequencyThreshold aFrequencyThreshold)Instantiates a new modem metrics impl.
-