ChannelSelectorAccessor.ChannelSelectorProperty, ModemMetricsModemMetricsImplpublic interface ChannelSelectorAccessor
| Modifier and Type | Interface | Description |
|---|---|---|
static interface |
ChannelSelectorAccessor.ChannelSelectorBuilder<B extends ChannelSelectorAccessor.ChannelSelectorBuilder<B>> |
Provides a builder method for a channel selector property returning the
builder for applying multiple build operations.
|
static interface |
ChannelSelectorAccessor.ChannelSelectorMutator |
Provides a mutator for a channel selector property.
|
static interface |
ChannelSelectorAccessor.ChannelSelectorProperty |
Provides a channel selector property.
|
| Modifier and Type | Method | Description |
|---|---|---|
ChannelSelector |
getChannelSelector() |
Retrieves the channel selector from the channel selector property.
|
ChannelSelector getChannelSelector()
Copyright © 2018. All rights reserved.